# parapint

[![codecov](https://codecov.io/gh/Parapint/Parapint/branch/master/graph/badge.svg)](https://codecov.io/gh/parapint/parapint)
[![Actions Status](https://github.com/parapint/parapint/workflows/main_ci/badge.svg?branch=master)](https://github.com/parapint/parapint/actions)
[![Documentation Status](https://readthedocs.org/projects/parapint/badge/?version=latest)](https://parapint.readthedocs.io/en/latest/?badge=latest)

Parapint is a Python package for parallel solution of structured nonlinear programs. Documentation for installation and usage can be found at https://parapint.readthedocs.io/en/latest/. You can also check out the examples (https://github.com/Parapint/parapint/tree/master/parapint/examples).
